pub struct InvalidHeaderError { /* private fields */ }Expand description
An error returned when the header of a bytecode input did not meet the official ivmc bytecode header format.
Implementations
Sourceimpl InvalidHeaderError
impl InvalidHeaderError
Sourcepub fn get_cause(&self) -> &InvalidHeaderCause
pub fn get_cause(&self) -> &InvalidHeaderCause
Get the cause of this error.
Sourcepub fn get_message(&self) -> &String
pub fn get_message(&self) -> &String
Get the message of this error.
pub fn new(cause: InvalidHeaderCause, message: String) -> Self
pub fn from(cause: InvalidHeaderCause, message: &str) -> Self